@@ -39,6 +39,32 @@ The modifiers `s`, `u`, `h`, `copy` (or `c`), and `cut` (or `x`) along with usin
 should cover most use cases. To learn about other existing modifiers, refer to the rest of this
 documentation.
 
+## Arguments For Handlers
+
+Neither `refinery.lib.argformats.DelayedArgument.s`, `refinery.lib.argformats.DelayedArgument.u`,
+nor `refinery.lib.argformats.DelayedArgument.h` require any additional arguments except for the
+input string that they are applied to. However, if a refinery unit is used as a handler, there is
+an option to add arguments to the handler that will be passed to the unit as command-line
+arguments. For example, the following will output the hexadecimal text representation of the MD5
+hash of the string "password":
+
+    emit md5[-t]:password
+
+Inside the square brackets that follow the handler name, arguments are separated by commas. This
+also means that arguments passed to handlers in this way cannot contain any commas. There is no
+escape sequence, but it is possible to use nested multibin expressions to work around this. For
+example, the multibin expression `q:1%2c2%2c3` corresponds to the string `1,2,3` and the output
+of the following command will be `2,4,5`:
+
+    emit repl[q:1%2c2%2c3,2]:1,2,3,4,5
+
+The first argument to the `refinery.repl` unit is the multibin argument `q:1%2c2%2c3`, which uses
+the `refinery.lib.argformats.DelayedArgument.q` handler to return `1,2,3`. The second argument to
+this unit-based handler is `2`, separated from the previous one by a comma. Hence, `refinery.repl`
+will replace all occurrences of `1,2,3` in the input with just `2`.
+
+Some of the more complex non-unit handlers also have optional arguments.
+
 ## Technical Details
 
 This module implements all argument parser types for the binary refinery. Notable classes for the
@@ -213,7 +239,7 @@ class SliceAgain(LazyEvaluation):
         return sliceobj(expression, metavars(data))
 
 
-def sliceobj(expression: Union[int, str, slice], variables: Optional[dict] = None, range=False) -> slice:
+def sliceobj(expression: Union[int, str, slice], variables: Optional[dict] = None, range=False) -> Union[slice, SliceAgain]:
     """
     Uses `refinery.lib.argformats.PythonExpression` to parse slice expressions
     where the bounds can be given as arithmetic expressions. For example, this
@@ -591,6 +617,14 @@ class DelayedArgument(LazyEvaluation):
         import base64
         return base64.b16decode(string, casefold=True)
 
+    @handler.register('q', 'Q', final=True)
+    def q(self, string: str) -> bytes:
+        """
+        The final modifier `q:string` (or `Q:string`) returns the url-quote decoding of `string`.
+        """
+        import urllib.parse
+        return urllib.parse.unquote_to_bytes(string)
+
     @handler.register('f', 'F', final=True)
     def f(self, path: str, region: str = None) -> bytes:
         """
@@ -824,16 +858,20 @@ class DelayedArgument(LazyEvaluation):
         to it. Slices are given in Python syntax, so `take[::2]` will extract every second item from
         the incoming data. The default sequence is `1:`, i.e. skipping the first element.
         """
-        bounds = bounds and sliceobj(bounds, {}) or slice(1, None)
-        try:
-            return it[bounds]
-        except TypeError:
-            subsequence = itertools.islice(it, bounds.start, bounds.stop, bounds.step)
-            if bounds.stop is not None:
-                subsequence = list(subsequence)
-                if all(t in range(0x100) for t in subsequence):
-                    subsequence = bytearray(subsequence)
-            return subsequence
+        def sliced(bounds):
+            try:
+                return it[bounds]
+            except TypeError:
+                subsequence = itertools.islice(it, bounds.start, bounds.stop, bounds.step)
+                if bounds.stop is not None:
+                    subsequence = list(subsequence)
+                    if all(t in range(0x100) for t in subsequence):
+                        subsequence = bytearray(subsequence)
+                return subsequence
+        bounds = bounds and sliceobj(bounds) or slice(1, None)
+        if isinstance(bounds, slice):
+            return sliced(bounds)
+        return lambda d: sliced(bounds(d))
 
     @handler.register('cycle')
     def cycle(self, it: Iterable[int]) -> Iterable[int]:
@@ -999,6 +1037,11 @@ class DelayedNumSeqArgument(DelayedArgument):
         Attempts to parse the input expression as a sequence of integers. If this fails, the handler defaults
         to the parent `refinery.lib.argformats.DelayedArgument.default_handler`.
         """
+        try:
+            with open(expression, 'rb') as stream:
+                return stream.read()
+        except Exception:
+            pass
         try:
             return LazyPythonExpression(expression)
         except Exception:
