@@ -83,7 +83,6 @@ from __future__ import annotations
 import abc
 import contextlib
 import hashlib
-import os
 import string
 import zlib
 import codecs
@@ -125,12 +124,12 @@ class ByteStringWrapper(bytearray, CustomStringRepresentation):
         for c, p in [('utf8', 's'), ('latin1', 'a'), ('utf-16le', 'u')]
     }
 
-    def __init__(self, string: Union[str, ByteString], codec: Optional[str] = None, error: str = 'backslashreplace'):
+    def __init__(self, string: Union[str, ByteString], codec: Optional[str] = None):
         if isinstance(string, str):
             self._string = string
             self._buffer = False
             codec = codec or 'utf8'
-            string = string.encode(codec, error)
+            string = string.encode(codec)
         elif isbuffer(string):
             self._string = None
             self._buffer = True
@@ -146,21 +145,14 @@ class ByteStringWrapper(bytearray, CustomStringRepresentation):
             codec = nc
 
         self.codec = codec
-        self.error = error
 
     def __fspath__(self):
         return self.string
 
     def requires_prefix(self) -> bool:
         try:
-            if os.path.isfile(self.string):
-                return True
-        except Exception:
-            pass
-        try:
-            from refinery.lib.argformats import DelayedBinaryArgument
-            dba = DelayedBinaryArgument(self.string)
-            return dba() != self
+            from refinery.lib.argformats import DelayedArgument
+            return bool(DelayedArgument(self.string).modifiers)
         except Exception:
             return True
 
@@ -172,7 +164,7 @@ class ByteStringWrapper(bytearray, CustomStringRepresentation):
             codecs = self._CODECS if _codec is None else [_codec]
             for codec in codecs:
                 try:
-                    value = self.decode(codec, self.error)
+                    value = self.decode(codec)
                 except UnicodeDecodeError:
                     pass
                 else:
@@ -464,6 +456,8 @@ class LazyMetaOracle(dict, metaclass=_LazyMetaMeta):
             ):
                 for key, value in it:
                     with contextlib.suppress(TypeError):
+                        if isinstance(value, CustomStringRepresentation):
+                            continue
                         store[key] = ByteStringWrapper(value, codec)
 
         formatter = string.Formatter()
