@@ -34,8 +34,13 @@ class xtiso(ArchiveUnit):
         pycdlib.dates.VolumeDescriptorDate.parse = fixed_parse
         return pycdlib
 
+    @staticmethod
+    def _strip_revision(name: str):
+        base, split, revision = name.partition(';')
+        return base if split and revision.isdigit() else name
+
     def unpack(self, data):
-        with MemoryFile(data) as stream:
+        with MemoryFile(data, read_as_bytes=True) as stream:
             iso = self._pycdlib.PyCdlib()
             iso.open_fp(stream)
             fs = self.args.fs
@@ -48,12 +53,16 @@ class xtiso(ArchiveUnit):
                 }
                 facade = mkfacade[fs]()
             elif iso.has_udf():
+                self.log_info('using format: udf')
                 facade = iso.get_udf_facade()
             elif iso.has_joliet():
+                self.log_info('using format: joliet')
                 facade = iso.get_joliet_facade()
             elif iso.has_rock_ridge():
+                self.log_info('using format: rr')
                 facade = iso.get_rock_ridge_facade()
             else:
+                self.log_info('using format: iso')
                 facade = iso.get_iso9660_facade()
 
             for root, _, files in facade.walk('/'):
@@ -85,4 +94,11 @@ class xtiso(ArchiveUnit):
                         facade.get_file_from_iso_fp(buffer, path)
                         return buffer.getvalue()
 
-                    yield self._pack(path, date, extract)
+                    yield self._pack(self._strip_revision(path), date, extract)
+
+    def handles(self, data: bytearray) -> bool:
+        return any(data[k] == B'CD001' for k in (
+            slice(0x8001, 0x8006),
+            slice(0x8801, 0x8806),
+            slice(0x9001, 0x9006),
+        ))
